@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: mmorph
-version: 1.0.5
-id: mmorph-1.0.5-e60c02bbf8b77eebbfba87226239c06b
-key: mmorp_EsJtL6n9y2HIe44mBcTsVR
+version: 1.0.6
+id: mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
+key: mmorp_2Jm5FlYBlmjDhcU1ovZRKP
 license: BSD3
 copyright: 2013 Gabriel Gonzalez
 maintainer: Gabriel439@gmail.com
@@ -17,13 +17,15 @@ exposed: True
 exposed-modules:
     Control.Monad.Morph Control.Monad.Trans.Compose
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/mmorph-1.0.5
-library-dirs: /usr/lib/ghc-7.10.3/site-local/mmorph-1.0.5
-data-dir: /usr/share/arm-linux-ghc-7.10.3/mmorph-1.0.5
-hs-libraries: HSmmorph-1.0.5-EsJtL6n9y2HIe44mBcTsVR
+import-dirs: /usr/lib/ghc-7.10.3/site-local/mmorph-1.0.6
+library-dirs: /usr/lib/ghc-7.10.3/site-local/mmorph-1.0.6
+data-dir: /usr/share/arm-linux-ghc-7.10.3/mmorph-1.0.6
+hs-libraries: HSmmorph-1.0.6-2Jm5FlYBlmjDhcU1ovZRKP
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
+    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
+    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
 haddock-interfaces: /usr/share/doc/haskell-mmorph/html/mmorph.haddock
 haddock-html: /usr/share/doc/haskell-mmorph/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
